# Individual Software Project

## Project Idea

The goal of the project is to implement several Reinforcement Learning agents for [Nethack Learning Environment](https://github.com/facebookresearch/nle)
